Partition Objects
=================

.. toctree::
   :caption: API Reference
   :maxdepth: 2

CubePartition
-------------

.. autoclass:: cr.cube.cubepart.CubePartition
   :members:

Slice
-----

.. autoclass:: cr.cube.cubepart._Slice
   :members:

Strand
------

.. autoclass:: cr.cube.cubepart._Strand
   :members:

Nub
---

.. autoclass:: cr.cube.cubepart._Nub
   :members:

.. toctree::
